@@ -35,6 +35,12 @@ from .models import (
 
 # plugin interface
 
+__version__ = "1.0.0"
+
+
+def version():
+    return __version__
+
 
 class Service(metaclass=ABCMeta):
     """
@@ -240,7 +246,7 @@ class EngineAPIHooksMixin:
 
     @abstractmethod
     def pre_prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
     ):
         """
         调用 pre_prepare_run_pipeline 前执行的钩子
@@ -251,11 +257,13 @@ class EngineAPIHooksMixin:
         :type root_pipeline_data: dict
         :param root_pipeline_context 根流程上下文
         :type root_pipeline_context: dict
+        :param subprocess_context 子流程预置流程上下文
+        :type subprocess_context: dict
         """
 
     @abstractmethod
     def post_prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
     ):
         """
         调用 pre_prepare_run_pipeline 后执行的钩子
@@ -266,6 +274,8 @@ class EngineAPIHooksMixin:
         :type root_pipeline_data: dict
         :param root_pipeline_context 根流程上下文
         :type root_pipeline_context: dict
+        :param subprocess_context 子流程预置流程上下文
+        :type subprocess_context: dict
         """
 
     @abstractmethod
@@ -1346,7 +1356,7 @@ class EngineRuntimeInterface(
 ):
     @abstractmethod
     def prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
     ) -> int:
         """
         进行 pipeline 执行前的准备工作，并返回 进程 ID，该函数执行完成后即代表
@@ -1362,6 +1372,8 @@ class EngineRuntimeInterface(
         :type root_pipeline_data: dict
         :param root_pipeline_context 根流程上下文
         :type root_pipeline_context: dict
+        :param subprocess_context 子流程预置流程上下文
+        :type subprocess_context: dict
         :return: 进程 ID
         :rtype: str
         """
